PyXMake Developer Guide: PyXMake.VTL.coverage Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.coverage Namespace Reference

## Functions
| main (BuildID, source=PyXMakePath, include=[os.path.join(PyXMakePath,"VTL","examples", 'pyx_api.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_cxx.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_py2x.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_gfortran.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_pyreq.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_doxygen.py'), os.path.join(PyXMakePath,"VTL","examples", 'pyx_openapi.py')], output=os.getcwd(), **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Run coverage inherited from pytest-cov with more meaningful default settings
    derived from Robot.

    Created on 31.01.2023

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.coverage.main | ( |  | BuildID,
|  |  | source = PyXMakePath,
|  |  | include = [ os.path.join(PyXMakePath,"VTL","examples",'pyx_api.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_cxx.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_py2x.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_gfortran.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_pyreq.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_doxygen.py'), os.path.join(PyXMakePath,"VTL","examples",'pyx_openapi.py') ],
|  |  | output = os.getcwd(),
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 36 of file coverage.py.